searchData={"items":[{"type":"module","title":"Nexlm","doc":"A unified interface (Nexus) for interacting with various Large Language Model\n(LLM) providers in Elixir.\n\nNexlm abstracts away provider-specific implementations while offering a clean,\nconsistent API for developers. This enables easy integration with different LLM\nservices like OpenAI's GPT, Anthropic's Claude, and Google's Gemini.","ref":"Nexlm.html"},{"type":"module","title":"Features - Nexlm","doc":"* Single, unified API for multiple LLM providers\n* Support for text and multimodal (image) inputs\n* Built-in validation and error handling\n* Configurable request parameters\n* Provider-agnostic message format\n* Caching support for reduced costs","ref":"Nexlm.html#module-features"},{"type":"module","title":"Provider Support - Nexlm","doc":"Currently supported providers:\n- OpenAI (GPT-4, GPT-3.5)\n- Anthropic (Claude)\n- Google (Gemini)","ref":"Nexlm.html#module-provider-support"},{"type":"module","title":"Model Names - Nexlm","doc":"Model names must be prefixed with the provider name:\n\n- `\"anthropic/claude-3-haiku-20240307\"`\n- `\"openai/gpt-4\"`\n- `\"google/gemini-pro\"`","ref":"Nexlm.html#module-model-names"},{"type":"module","title":"Basic Usage - Nexlm","doc":"#","ref":"Nexlm.html#module-basic-usage"},{"type":"module","title":"Simple Text Completion - Nexlm","doc":"messages = [%{\n      \"role\" => \"user\",\n      \"content\" => \"What is the capital of France?\"\n    }]\n\n    {:ok, response} = Nexlm.complete(\"anthropic/claude-3-haiku-20240307\", messages)\n    # => {:ok, %{role: \"assistant\", content: \"The capital of France is Paris.\"}}\n\n#","ref":"Nexlm.html#module-simple-text-completion"},{"type":"module","title":"With System Message - Nexlm","doc":"messages = [\n      %{\n        \"role\" => \"system\",\n        \"content\" => \"You are a mathematician who only responds with numbers\"\n      },\n      %{\n        \"role\" => \"user\",\n        \"content\" => \"What is five plus five?\"\n      }\n    ]\n\n    {:ok, response} = Nexlm.complete(\"openai/gpt-4\", messages, temperature: 0.7)\n    # => {:ok, %{role: \"assistant\", content: \"10\"}}\n\n#","ref":"Nexlm.html#module-with-system-message"},{"type":"module","title":"Image Analysis - Nexlm","doc":"image_data = File.read!(\"image.jpg\") |> Base.encode64()\n\n    messages = [\n      %{\n        \"role\" => \"user\",\n        \"content\" => [\n          %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n          %{\n            \"type\" => \"image\",\n            \"mime_type\" => \"image/jpeg\",\n            \"data\" => image_data,\n            \"cache\" => true  # Enable caching for this content\n          }\n        ]\n      }\n    ]\n\n    {:ok, response} = Nexlm.complete(\n      \"google/gemini-pro-vision\",\n      messages,\n      max_tokens: 100\n    )","ref":"Nexlm.html#module-image-analysis"},{"type":"module","title":"Configuration - Nexlm","doc":"Configure provider API keys in your application's runtime configuration:\n\n    # config/runtime.exs\n    config :nexlm, Nexlm.Providers.OpenAI,\n      api_key: System.get_env(\"OPENAI_API_KEY\")\n\n    config :nexlm, Nexlm.Providers.Anthropic,\n      api_key: System.get_env(\"ANTHROPIC_API_KEY\")\n\n    config :nexlm, Nexlm.Providers.Google,\n      api_key: System.get_env(\"GOOGLE_API_KEY\")","ref":"Nexlm.html#module-configuration"},{"type":"module","title":"Error Handling - Nexlm","doc":"The library provides structured error handling:\n\n    case Nexlm.complete(model, messages, opts) do\n      {:ok, response} ->\n        handle_success(response)\n\n      {:error, %Nexlm.Error{type: :rate_limit_error}} ->\n        apply_rate_limit_backoff()\n\n      {:error, %Nexlm.Error{type: :provider_error, message: msg}} ->\n        Logger.error(\"Provider error: #{msg}\")\n        handle_provider_error()\n\n      {:error, error} ->\n        Logger.error(\"Unexpected error: #{inspect(error)}\")\n        handle_generic_error()\n    end","ref":"Nexlm.html#module-error-handling"},{"type":"module","title":"Message Format - Nexlm","doc":"#","ref":"Nexlm.html#module-message-format"},{"type":"module","title":"Simple Text Message - Nexlm","doc":"%{\n      \"role\" => \"user\",  # \"user\", \"assistant\", or \"system\"\n      \"content\" => \"Hello, world!\"\n    }\n\n#","ref":"Nexlm.html#module-simple-text-message"},{"type":"module","title":"Message with Image - Nexlm","doc":"%{\n      \"role\" => \"user\",\n      \"content\" => [\n        %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n        %{\n          \"type\" => \"image\",\n          \"mime_type\" => \"image/jpeg\",\n          \"data\" => \"base64_encoded_data\",\n          \"cache\" => true  # Optional caching flag\n        }\n      ]\n    }\n\n#","ref":"Nexlm.html#module-message-with-image"},{"type":"module","title":"System Message - Nexlm","doc":"%{\n      \"role\" => \"system\",\n      \"content\" => \"You are a helpful assistant\"\n    }","ref":"Nexlm.html#module-system-message"},{"type":"module","title":"Content Caching - Nexlm","doc":"Nexlm supports provider-level message caching through content item configuration:\n\n    # Image with caching enabled\n    %{\n      \"type\" => \"image\",\n      \"mime_type\" => \"image/jpeg\",\n      \"data\" => \"base64_data\",\n      \"cache\" => true  # Enable caching\n    }\n\nCurrently supported by:\n- Anthropic (via `cache_control` in content items)\n- Other providers may add support in future updates","ref":"Nexlm.html#module-content-caching"},{"type":"function","title":"Nexlm.complete/3","doc":"Sends a request to an LLM provider and returns the response.\n\nThis is the main entry point for interacting with LLM providers. It handles:\n- Message validation\n- Provider selection and configuration\n- Request formatting\n- Error handling\n- Response parsing","ref":"Nexlm.html#complete/3"},{"type":"function","title":"Arguments - Nexlm.complete/3","doc":"* `model` - String in the format \"provider/model-name\" (e.g., \"anthropic/claude-3\")\n  * `messages` - List of message maps with :role and :content keys\n  * `opts` - Optional keyword list of settings","ref":"Nexlm.html#complete/3-arguments"},{"type":"function","title":"Options - Nexlm.complete/3","doc":"* `:temperature` - Float between 0 and 1 (default: 0.0)\n  * `:max_tokens` - Maximum tokens in response\n  * `:top_p` - Float between 0 and 1\n  * `:receive_timeout` - Timeout in milliseconds (default: 300_000)\n  * `:retry_count` - Number of retry attempts (default: 3)\n  * `:retry_delay` - Delay between retries in milliseconds (default: 1000)","ref":"Nexlm.html#complete/3-options"},{"type":"function","title":"Examples - Nexlm.complete/3","doc":"#","ref":"Nexlm.html#complete/3-examples"},{"type":"function","title":"Simple text completion: - Nexlm.complete/3","doc":"messages = [%{\"role\" => \"user\", \"content\" => \"What's 2+2?\"}]\n    {:ok, response} = Nexlm.complete(\"anthropic/claude-3-haiku-20240307\", messages)\n    # => {:ok, %{role: \"assistant\", content: \"4\"}}\n\n#","ref":"Nexlm.html#complete/3-simple-text-completion"},{"type":"function","title":"With system message and temperature: - Nexlm.complete/3","doc":"messages = [\n      %{\"role\" => \"system\", \"content\" => \"Respond like a pirate\"},\n      %{\"role\" => \"user\", \"content\" => \"Hello\"}\n    ]\n    {:ok, response} = Nexlm.complete(\"openai/gpt-4\", messages, temperature: 0.7)\n    # => {:ok, %{role: \"assistant\", content: \"Arr, ahoy there matey!\"}}\n\n#","ref":"Nexlm.html#complete/3-with-system-message-and-temperature"},{"type":"function","title":"With image analysis: - Nexlm.complete/3","doc":"messages = [\n      %{\n        \"role\" => \"user\",\n        \"content\" => [\n          %{\"type\" => \"text\", \"text\" => \"Describe this image:\"},\n          %{\n            \"type\" => \"image\",\n            \"mime_type\" => \"image/jpeg\",\n            \"data\" => \"base64_data\",\n            \"cache\" => true\n          }\n        ]\n      }\n    ]\n    {:ok, response} = Nexlm.complete(\n      \"google/gemini-pro-vision\",\n      messages,\n      max_tokens: 200\n    )","ref":"Nexlm.html#complete/3-with-image-analysis"},{"type":"function","title":"Returns - Nexlm.complete/3","doc":"Returns either:\n- `{:ok, message}` - Success response with assistant's message\n- `{:error, error}` - Error tuple with Nexlm.Error struct","ref":"Nexlm.html#complete/3-returns"},{"type":"function","title":"Error Handling - Nexlm.complete/3","doc":"Possible error types:\n- `:validation_error` - Invalid message format or content\n- `:provider_error` - Provider-specific API errors\n- `:rate_limit_error` - Rate limit exceeded\n- `:timeout_error` - Request timeout\n- `:configuration_error` - Invalid configuration","ref":"Nexlm.html#complete/3-error-handling"},{"type":"type","title":"Nexlm.content_item/0","doc":"A content item in a message, used for multimodal inputs.\n\nFields:\n- type: The type of content (\"text\" or \"image\")\n- text: The text content for text type items\n- mime_type: The MIME type for image content (e.g., \"image/jpeg\")\n- data: Base64 encoded image data\n- cache: Whether this content should be cached by the provider","ref":"Nexlm.html#t:content_item/0"},{"type":"type","title":"Nexlm.message/0","doc":"A message that can be sent to an LLM provider.\n\nFields:\n- role: The role of the message sender (\"user\", \"assistant\", or \"system\")\n- content: The content of the message, either a string or a list of content items","ref":"Nexlm.html#t:message/0"},{"type":"behaviour","title":"Nexlm.Behaviour","doc":"","ref":"Nexlm.Behaviour.html"},{"type":"callback","title":"Nexlm.Behaviour.call/2","doc":"","ref":"Nexlm.Behaviour.html#c:call/2"},{"type":"callback","title":"Nexlm.Behaviour.format_request/2","doc":"","ref":"Nexlm.Behaviour.html#c:format_request/2"},{"type":"callback","title":"Nexlm.Behaviour.init/1","doc":"","ref":"Nexlm.Behaviour.html#c:init/1"},{"type":"callback","title":"Nexlm.Behaviour.parse_response/1","doc":"","ref":"Nexlm.Behaviour.html#c:parse_response/1"},{"type":"callback","title":"Nexlm.Behaviour.validate_messages/1","doc":"","ref":"Nexlm.Behaviour.html#c:validate_messages/1"},{"type":"type","title":"Nexlm.Behaviour.message/0","doc":"","ref":"Nexlm.Behaviour.html#t:message/0"},{"type":"type","title":"Nexlm.Behaviour.tool_call/0","doc":"","ref":"Nexlm.Behaviour.html#t:tool_call/0"},{"type":"type","title":"Nexlm.Behaviour.tool_definition/0","doc":"","ref":"Nexlm.Behaviour.html#t:tool_definition/0"},{"type":"type","title":"Nexlm.Behaviour.tool_result/0","doc":"","ref":"Nexlm.Behaviour.html#t:tool_result/0"},{"type":"module","title":"Nexlm.Config","doc":"","ref":"Nexlm.Config.html"},{"type":"function","title":"Nexlm.Config.new/1","doc":"","ref":"Nexlm.Config.html#new/1"},{"type":"function","title":"Nexlm.Config.validate/1","doc":"","ref":"Nexlm.Config.html#validate/1"},{"type":"function","title":"Nexlm.Config.validate!/1","doc":"","ref":"Nexlm.Config.html#validate!/1"},{"type":"module","title":"Nexlm.Message","doc":"","ref":"Nexlm.Message.html"},{"type":"function","title":"Nexlm.Message.validate/1","doc":"","ref":"Nexlm.Message.html#validate/1"},{"type":"function","title":"Nexlm.Message.validate!/1","doc":"","ref":"Nexlm.Message.html#validate!/1"},{"type":"function","title":"Nexlm.Message.validate_message/1","doc":"","ref":"Nexlm.Message.html#validate_message/1"},{"type":"function","title":"Nexlm.Message.validate_messages/1","doc":"","ref":"Nexlm.Message.html#validate_messages/1"},{"type":"module","title":"Nexlm.Message.Content","doc":"Message validation and formatting for LLM providers.\n\nProvides a common structure for messages that can be sent to any LLM provider,\nwith validation and conversion utilities.","ref":"Nexlm.Message.Content.html"},{"type":"module","title":"Message Structure - Nexlm.Message.Content","doc":"```elixir\n%{\n  role: \"user\" | \"assistant\" | \"system\",\n  content: String.t() | [ContentItem.t()]\n}\n```","ref":"Nexlm.Message.Content.html#module-message-structure"},{"type":"module","title":"Content Types - Nexlm.Message.Content","doc":"- Text: Simple string content\n- Image: Base64 encoded image with mime type","ref":"Nexlm.Message.Content.html#module-content-types"},{"type":"module","title":"Examples - Nexlm.Message.Content","doc":"# Text message\n    %{\n      \"role\" => \"user\",\n      \"content\" => \"Hello, how are you?\"\n    }\n\n    # Message with image\n    %{\n      \"role\" => \"user\",\n      \"content\" => [\n        %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n        %{\n          \"type\" => \"image\",\n          \"mime_type\" => \"image/jpeg\",\n          \"data\" => \"base64_data\"\n        }\n      ]\n    }","ref":"Nexlm.Message.Content.html#module-examples"},{"type":"function","title":"Nexlm.Message.Content.validate/1","doc":"","ref":"Nexlm.Message.Content.html#validate/1"},{"type":"function","title":"Nexlm.Message.Content.validate!/1","doc":"","ref":"Nexlm.Message.Content.html#validate!/1"},{"type":"module","title":"Nexlm.Message.ToolCall","doc":"","ref":"Nexlm.Message.ToolCall.html"},{"type":"function","title":"Nexlm.Message.ToolCall.validate/1","doc":"","ref":"Nexlm.Message.ToolCall.html#validate/1"},{"type":"function","title":"Nexlm.Message.ToolCall.validate!/1","doc":"","ref":"Nexlm.Message.ToolCall.html#validate!/1"},{"type":"module","title":"Nexlm.Providers.Anthropic","doc":"Provider implementation for Anthropic's Claude API.","ref":"Nexlm.Providers.Anthropic.html"},{"type":"module","title":"Model Names - Nexlm.Providers.Anthropic","doc":"Models should be prefixed with \"anthropic/\", for example:\n- \"anthropic/claude-3-haiku-20240307\"\n- \"anthropic/claude-3-opus-20240229\"","ref":"Nexlm.Providers.Anthropic.html#module-model-names"},{"type":"module","title":"Message Formats - Nexlm.Providers.Anthropic","doc":"Supports the following message types:\n- Text messages: Simple string content\n- System messages: Special instructions for model behavior\n- Image messages: Base64 encoded images with mime type","ref":"Nexlm.Providers.Anthropic.html#module-message-formats"},{"type":"module","title":"Configuration - Nexlm.Providers.Anthropic","doc":"Required:\n- API key in runtime config (:nexlm, Nexlm.Providers.Anthropic, api_key: \"key\")\n- Model name in request","ref":"Nexlm.Providers.Anthropic.html#module-configuration"},{"type":"module","title":"Examples - Nexlm.Providers.Anthropic","doc":"# Simple text completion\n    config = Anthropic.init(model: \"anthropic/claude-3-haiku-20240307\")\n    messages = [%{\"role\" => \"user\", \"content\" => \"Hello\"}]\n    {:ok, response} = Anthropic.call(config, messages)\n\n    # With system message\n    messages = [\n      %{\"role\" => \"system\", \"content\" => \"You are a helpful assistant\"},\n      %{\"role\" => \"user\", \"content\" => \"Hello\"}\n    ]\n\n    # With image input\n    messages = [\n      %{\n        \"role\" => \"user\",\n        \"content\" => [\n          %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n          %{\n            \"type\" => \"image\",\n            \"mime_type\" => \"image/jpeg\",\n            \"data\" => \"base64_encoded_data\"\n          }\n        ]\n      }\n    ]","ref":"Nexlm.Providers.Anthropic.html#module-examples"},{"type":"module","title":"Nexlm.Providers.Google","doc":"Provider implementation for Google's Gemini API.","ref":"Nexlm.Providers.Google.html"},{"type":"module","title":"Model Names - Nexlm.Providers.Google","doc":"Models should be prefixed with \"google/\", for example:\n- \"google/gemini-1.5-flash-latest\"\n- \"google/gemini-1.5-pro-latest\"","ref":"Nexlm.Providers.Google.html#module-model-names"},{"type":"module","title":"Message Formats - Nexlm.Providers.Google","doc":"Supports the following message types:\n- Text messages: Simple string content\n- System messages: Special instructions using systemInstruction format\n- Image messages: Base64 encoded images with mime type","ref":"Nexlm.Providers.Google.html#module-message-formats"},{"type":"module","title":"Configuration - Nexlm.Providers.Google","doc":"Required:\n- API key in runtime config (:nexlm, Nexlm.Providers.Google, api_key: \"key\")\n- Model name in request\n\nOptional:\n- temperature: Float between 0 and 1 (default: 0.0)\n- max_tokens: Integer for response length limit\n- top_p: Float between 0 and 1 (default: 0.95)","ref":"Nexlm.Providers.Google.html#module-configuration"},{"type":"module","title":"Examples - Nexlm.Providers.Google","doc":"# Simple text completion\n    config = Google.init(model: \"google/gemini-1.5-flash-latest\")\n    messages = [%{\"role\" => \"user\", \"content\" => \"Hello\"}]\n    {:ok, response} = Google.call(config, messages)\n\n    # With system instruction\n    messages = [\n      %{\"role\" => \"system\", \"content\" => \"You are a helpful assistant\"},\n      %{\"role\" => \"user\", \"content\" => \"Hello\"}\n    ]\n\n    # With image input\n    messages = [\n      %{\n        \"role\" => \"user\",\n        \"content\" => [\n          %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n          %{\n            \"type\" => \"image\",\n            \"mime_type\" => \"image/jpeg\",\n            \"data\" => \"base64_encoded_data\"\n          }\n        ]\n      }\n    ]","ref":"Nexlm.Providers.Google.html#module-examples"},{"type":"module","title":"Safety Settings - Nexlm.Providers.Google","doc":"Default safety settings are applied to prevent harmful content:\n- HARM_CATEGORY_HATE_SPEECH\n- HARM_CATEGORY_DANGEROUS_CONTENT\n- HARM_CATEGORY_SEXUALLY_EXPLICIT\n- HARM_CATEGORY_HARASSMENT","ref":"Nexlm.Providers.Google.html#module-safety-settings"},{"type":"module","title":"Nexlm.Providers.Groq","doc":"Provider implementation for Groq's Chat Completion API.\nGroq API is OpenAI-compatible with some limitations.","ref":"Nexlm.Providers.Groq.html"},{"type":"module","title":"Model Names - Nexlm.Providers.Groq","doc":"Models should be prefixed with \"groq/\", for example:\n- \"groq/mixtral-8x7b-32768\"\n- \"groq/llama2-70b-4096\"","ref":"Nexlm.Providers.Groq.html#module-model-names"},{"type":"module","title":"Message Formats - Nexlm.Providers.Groq","doc":"Supports the following message types:\n- Text messages: Simple string content\n- System messages: Special instructions for model behavior\n\nNote: Image messages are not supported.","ref":"Nexlm.Providers.Groq.html#module-message-formats"},{"type":"module","title":"Configuration - Nexlm.Providers.Groq","doc":"Required:\n- API key in runtime config (:nexlm, Nexlm.Providers.Groq, api_key: \"key\")\n- Model name in request\n\nOptional:\n- temperature: Float between 0 and 2 (default: 0.0, will be converted to 1e-8 if 0)\n- max_tokens: Integer for response length limit\n- top_p: Float between 0 and 1 for nucleus sampling","ref":"Nexlm.Providers.Groq.html#module-configuration"},{"type":"module","title":"Limitations - Nexlm.Providers.Groq","doc":"The following OpenAI features are not supported:\n- logprobs\n- logit_bias\n- top_logprobs\n- messages[].name\n- N > 1 (only single completions supported)","ref":"Nexlm.Providers.Groq.html#module-limitations"},{"type":"module","title":"Nexlm.Providers.OpenAI","doc":"Provider implementation for OpenAI's Chat Completion API.","ref":"Nexlm.Providers.OpenAI.html"},{"type":"module","title":"Model Names - Nexlm.Providers.OpenAI","doc":"Models should be prefixed with \"openai/\", for example:\n- \"openai/gpt-4\"\n- \"openai/gpt-4-vision-preview\"\n- \"openai/gpt-3.5-turbo\"","ref":"Nexlm.Providers.OpenAI.html#module-model-names"},{"type":"module","title":"Message Formats - Nexlm.Providers.OpenAI","doc":"Supports the following message types:\n- Text messages: Simple string content\n- System messages: Special instructions for model behavior\n- Image messages: Base64 encoded images or URLs (converted to data URLs)","ref":"Nexlm.Providers.OpenAI.html#module-message-formats"},{"type":"module","title":"Configuration - Nexlm.Providers.OpenAI","doc":"Required:\n- API key in runtime config (:nexlm, Nexlm.Providers.OpenAI, api_key: \"key\")\n- Model name in request\n\nOptional:\n- temperature: Float between 0 and 1 (default: 0.0)\n- max_tokens: Integer for response length limit\n- top_p: Float between 0 and 1 for nucleus sampling","ref":"Nexlm.Providers.OpenAI.html#module-configuration"},{"type":"module","title":"Examples - Nexlm.Providers.OpenAI","doc":"# Simple text completion\n  config = OpenAI.init(model: \"openai/gpt-4\")\n  messages = [%{\"role\" => \"user\", \"content\" => \"Hello\"}]\n  {:ok, response} = OpenAI.call(config, messages)\n\n  # Vision API with image\n  messages = [\n    %{\n      \"role\" => \"user\",\n      \"content\" => [\n        %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n        %{\n          \"type\" => \"image\",\n          \"mime_type\" => \"image/jpeg\",\n          \"data\" => \"base64_encoded_data\"\n        }\n      ]\n    }\n  ]\n  config = OpenAI.init(model: \"openai/gpt-4o-mini\")","ref":"Nexlm.Providers.OpenAI.html#module-examples"},{"type":"module","title":"Nexlm.Registry","doc":"","ref":"Nexlm.Registry.html"},{"type":"function","title":"Nexlm.Registry.get_provider/1","doc":"","ref":"Nexlm.Registry.html#get_provider/1"},{"type":"function","title":"Nexlm.Registry.list_providers/0","doc":"","ref":"Nexlm.Registry.html#list_providers/0"},{"type":"module","title":"Nexlm.Service","doc":"","ref":"Nexlm.Service.html"},{"type":"function","title":"Nexlm.Service.call/3","doc":"","ref":"Nexlm.Service.html#call/3"},{"type":"module","title":"Nexlm.Tool","doc":"","ref":"Nexlm.Tool.html"},{"type":"function","title":"Nexlm.Tool.validate/1","doc":"","ref":"Nexlm.Tool.html#validate/1"},{"type":"function","title":"Nexlm.Tool.validate!/1","doc":"","ref":"Nexlm.Tool.html#validate!/1"},{"type":"exception","title":"Nexlm.Error","doc":"","ref":"Nexlm.Error.html"},{"type":"function","title":"Nexlm.Error.new/4","doc":"","ref":"Nexlm.Error.html#new/4"},{"type":"type","title":"Nexlm.Error.error_type/0","doc":"","ref":"Nexlm.Error.html#t:error_type/0"},{"type":"type","title":"Nexlm.Error.t/0","doc":"","ref":"Nexlm.Error.html#t:t/0"},{"type":"extras","title":"Nexlm","doc":"# Nexlm\n\nA unified interface (Nexus) for interacting with various Large Language Model (LLM) providers in Elixir.\nNexlm abstracts away provider-specific implementations while offering a clean, consistent API for developers.","ref":"readme.html"},{"type":"extras","title":"Features - Nexlm","doc":"- Single, unified API for multiple LLM providers\n- Support for text and multimodal (image) inputs\n- Built-in validation and error handling\n- Configurable request parameters\n- Provider-agnostic message format\n- Caching support for reduced costs","ref":"readme.html#features"},{"type":"extras","title":"Supported Providers - Nexlm","doc":"- OpenAI (GPT-4, GPT-3.5)\n- Anthropic (Claude)\n- Google (Gemini)","ref":"readme.html#supported-providers"},{"type":"extras","title":"Installation - Nexlm","doc":"Add `nexlm` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nexlm, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Nexlm","doc":"Configure your API keys in `config/runtime.exs`:\n\n```elixir\nimport Config\n\nconfig :nexlm, Nexlm.Providers.OpenAI,\n  api_key: System.get_env(\"OPENAI_API_KEY\")\n\nconfig :nexlm, Nexlm.Providers.Anthropic,\n  api_key: System.get_env(\"ANTHROPIC_API_KEY\")\n\nconfig :nexlm, Nexlm.Providers.Google,\n  api_key: System.get_env(\"GOOGLE_API_KEY\")\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Basic Usage - Nexlm","doc":"#","ref":"readme.html#basic-usage"},{"type":"extras","title":"Simple Text Completion - Nexlm","doc":"```elixir\nmessages = [\n  %{\"role\" => \"user\", \"content\" => \"What is the capital of France?\"}\n]\n\n{:ok, response} = Nexlm.complete(\"anthropic/claude-3-haiku-20240307\", messages)\n# => {:ok, %{role: \"assistant\", content: \"The capital of France is Paris.\"}}\n```\n\n#","ref":"readme.html#simple-text-completion"},{"type":"extras","title":"With System Message - Nexlm","doc":"```elixir\nmessages = [\n  %{\n    \"role\" => \"system\",\n    \"content\" => \"You are a helpful assistant who always responds in JSON format\"\n  },\n  %{\n    \"role\" => \"user\",\n    \"content\" => \"List 3 European capitals\"\n  }\n]\n\n{:ok, response} = Nexlm.complete(\"openai/gpt-4\", messages, temperature: 0.7)\n```\n\n#","ref":"readme.html#with-system-message"},{"type":"extras","title":"Image Analysis - Nexlm","doc":"```elixir\nimage_data = File.read!(\"image.jpg\") |> Base.encode64()\n\nmessages = [\n  %{\n    \"role\" => \"user\",\n    \"content\" => [\n      %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n      %{\n        \"type\" => \"image\",\n        \"mime_type\" => \"image/jpeg\",\n        \"data\" => image_data,\n        \"cache\" => true  # Enable caching for this content\n      }\n    ]\n  }\n]\n\n{:ok, response} = Nexlm.complete(\n  \"google/gemini-pro-vision\",\n  messages,\n  max_tokens: 100\n)\n```\n\n#","ref":"readme.html#image-analysis"},{"type":"extras","title":"Tool Usage - Nexlm","doc":"(Currently, only supported by the Anthropic provider)\n\n```elixir\n# Define available tools\ntools = [\n  %{\n    name: \"get_weather\",\n    description: \"Get the weather for a location\",\n    parameters: %{\n      type: \"object\",\n      properties: %{\n        location: %{\n          type: \"string\",\n          description: \"The city and state, e.g. San Francisco, CA\"\n        }\n      },\n      required: [\"location\"]\n    }\n  }\n]\n\n# Initial message\nmessages = [\n  %{\"role\" => \"user\", \"content\" => \"What's the weather in London?\"}\n]\n\n# First call - model will request weather data\n{:ok, response} = Nexlm.complete(\n  \"anthropic/claude-3-haiku-20240307\",\n  messages,\n  tools: tools\n)\n\n# Handle tool call\n[%{id: tool_call_id, name: \"get_weather\", arguments: %{\"location\" => \"London\"}}] =\n  response.tool_calls\n\n# Add tool response to messages\nmessages = messages ++ [\n  response,\n  %{\n    \"role\" => \"tool\",\n    \"tool_call_id\" => tool_call_id,\n    \"content\" => \"sunny\"\n  }\n]\n\n# Final call - model will incorporate tool response\n{:ok, response} = Nexlm.complete(\n  \"anthropic/claude-3-haiku-20240307\",\n  messages,\n  tools: tools\n)\n# => {:ok, %{role: \"assistant\", content: \"The weather in London is sunny.\"}}\n```","ref":"readme.html#tool-usage"},{"type":"extras","title":"Error Handling - Nexlm","doc":"```elixir\ncase Nexlm.complete(model, messages, opts) do\n  {:ok, response} ->\n    handle_success(response)\n\n  {:error, %Nexlm.Error{type: :rate_limit_error}} ->\n    apply_rate_limit_backoff()\n\n  {:error, %Nexlm.Error{type: :provider_error, message: msg}} ->\n    Logger.error(\"Provider error: #{msg}\")\n    handle_provider_error()\n\n  {:error, error} ->\n    Logger.error(\"Unexpected error: #{inspect(error)}\")\n    handle_generic_error()\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Model Names - Nexlm","doc":"Model names must be prefixed with the provider name:\n\n- `\"anthropic/claude-3-haiku-20240307\"`\n- `\"openai/gpt-4\"`\n- `\"google/gemini-pro\"`","ref":"readme.html#model-names"},{"type":"extras","title":"Configuration Options - Nexlm","doc":"Available options for `Nexlm.complete/3`:\n\n- `:temperature` - Float between 0 and 1 (default: 0.0)\n- `:max_tokens` - Maximum tokens in response\n- `:top_p` - Float between 0 and 1 for nucleus sampling\n- `:receive_timeout` - Timeout in milliseconds (default: 300_000)\n- `:retry_count` - Number of retry attempts (default: 3)\n- `:retry_delay` - Delay between retries in milliseconds (default: 1000)","ref":"readme.html#configuration-options"},{"type":"extras","title":"Message Format - Nexlm","doc":"#","ref":"readme.html#message-format"},{"type":"extras","title":"Simple Text Message - Nexlm","doc":"```elixir\n%{\n  \"role\" => \"user\",\n  \"content\" => \"Hello, world!\"\n}\n```\n\n#","ref":"readme.html#simple-text-message"},{"type":"extras","title":"Message with Image - Nexlm","doc":"```elixir\n%{\n  \"role\" => \"user\",\n  \"content\" => [\n    %{\"type\" => \"text\", \"text\" => \"What's in this image?\"},\n    %{\n      \"type\" => \"image\",\n      \"mime_type\" => \"image/jpeg\",\n      \"data\" => \"base64_encoded_data\"\n    }\n  ]\n}\n```\n\n#","ref":"readme.html#message-with-image"},{"type":"extras","title":"System Message - Nexlm","doc":"```elixir\n%{\n  \"role\" => \"system\",\n  \"content\" => \"You are a helpful assistant\"\n}\n```","ref":"readme.html#system-message"},{"type":"extras","title":"Contributing - Nexlm","doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/my-feature`)\n3. Run tests (`mix test`)\n4. Commit your changes\n5. Push to your branch\n6. Create a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"Testing - Nexlm","doc":"Run the test suite:\n\n```bash\n# Run unit tests only\nmake test\n\n# Run integration tests (requires API keys in .env.local)\nmake test.integration\n```","ref":"readme.html#testing"},{"type":"extras","title":"License - Nexlm","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}